#include "esp_log.h"
#include "esp_partition.h"
#include "esp_ota_ops.h"

#include "ota.h"
#include "storage.h"

#include <string.h>

const char *TAG = "ota";

bool ota_perform_update(const char *version)
{
    const esp_partition_t *configured = esp_ota_get_boot_partition();
    const esp_partition_t *running = esp_ota_get_running_partition();

    if (configured != running)
    {
        ESP_LOGW(TAG, "Configured OTA boot partition at offset 0x%08" PRIx32 ", but running from offset 0x%08" PRIx32,
                 configured->address, running->address);
        ESP_LOGW(TAG, "(This can happen if either the OTA boot data or preferred boot image become corrupted somehow.)");
    }

    ESP_LOGI(TAG, "Running partition type %d subtype %d (offset 0x%08" PRIx32 ")",
             running->type, running->subtype, running->address);

    // Determine firmware download URL
    char *secure_url = calloc(256, 1);
    assert(secure_url != NULL);
    assert(storage_get_secure_origin(secure_url) > 0);
    strcat(secure_url, "/devices_api/ota/Wt32-Eth01/");
    strcat(secure_url, version);
    ESP_LOGI(TAG, "Firmware URL: %s", secure_url);

    free(secure_url);

    // TODO (from native example)
    return false;
}